@@ -11,22 +11,22 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: config.h,v 1.39 2005/09/24 09:19:28 xleroy Exp $ */
+/* $Id: config.h,v 1.42.4.1 2008/11/02 14:30:05 xleroy Exp $ */
 
 #ifndef CAML_CONFIG_H
 #define CAML_CONFIG_H
 
-#undef ARCH_SIXTYFOUR
+#define ARCH_SIXTYFOUR
 #define SIZEOF_INT 4
-#define SIZEOF_LONG 4
-#define SIZEOF_PTR 4
+#define SIZEOF_LONG 8
+#define SIZEOF_PTR 8
 #define SIZEOF_SHORT 2
-#define ARCH_INT64_TYPE long long
-#define ARCH_UINT64_TYPE unsigned long long
-#define ARCH_INT64_PRINTF_FORMAT "ll"
+#define ARCH_INT64_TYPE long
+#define ARCH_UINT64_TYPE unsigned long
+#define ARCH_INT64_PRINTF_FORMAT "l"
 #define ARCH_BIG_ENDIAN
-#define ARCH_ALIGN_DOUBLE
-#define ARCH_ALIGN_INT64
+#undef ARCH_ALIGN_DOUBLE
+#undef ARCH_ALIGN_INT64
 #undef NONSTANDARD_DIV_MOD
 #define OCAML_OS_TYPE "Unix"
 #define OCAML_STDLIB_DIR "/usr/local/lib/ocaml"
@@ -133,7 +133,7 @@ typedef struct { uint32 l, h; } uint64, int64;
    float is at byte offset [a], the next lsb at [b], ..., and the
    most significant byte at [h]. */
 
-#if defined(__arm__)
+#if defined(__arm__) && !defined(__ARM_EABI__)
 #define ARCH_FLOAT_ENDIANNESS 0x45670123
 #elif defined(ARCH_BIG_ENDIAN)
 #define ARCH_FLOAT_ENDIANNESS 0x76543210
@@ -155,7 +155,7 @@ typedef struct { uint32 l, h; } uint64, int64;
 /* Memory model parameters */
 
 /* The size of a page for memory management (in bytes) is [1 << Page_log].
-   It must be a multiple of [sizeof (value)]. */
+   It must be a multiple of [sizeof (value)] and >= 8 and <= 20. */
 #define Page_log 12             /* A page is 4 kilobytes. */
 
 /* Initial size of stack (bytes). */
@@ -165,7 +165,7 @@ typedef struct { uint32 l, h; } uint64, int64;
 #define Stack_threshold (256 * sizeof(value))
 
 /* Default maximum size of the stack (words). */
-#define Max_stack_def (256 * 1024)
+#define Max_stack_def (1024 * 1024)
 
 
 /* Maximum size of a block allocated in the young generation (words). */
@@ -191,12 +191,13 @@ typedef struct { uint32 l, h; } uint64, int64;
 #define Heap_chunk_min (2 * Page_size / sizeof (value))
 
 /* Default size increment when growing the heap. (words)
-   Must be a multiple of [Page_size / sizeof (value)]. */
-#define Heap_chunk_def (15 * Page_size)
+   Must be a multiple of [Page_size / sizeof (value)].
+   (Approx 512 Kb for a 32-bit platform, 1 Mb for a 64-bit platform.) */
+#define Heap_chunk_def (31 * Page_size)
 
 /* Default initial size of the major heap (words);
    same constraints as for Heap_chunk_def. */
-#define Init_heap_def (15 * Page_size)
+#define Init_heap_def (31 * Page_size)
 
 
 /* Default speed setting for the major GC.  The heap will grow until
