@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: memory.h,v 1.54.2.3 2006/07/25 09:13:16 doligez Exp $ */
+/* $Id: memory.h,v 1.59.4.1 2008/11/02 14:30:05 xleroy Exp $ */
 
 /* Allocation macros and functions */
 
@@ -215,12 +215,14 @@ CAMLextern struct caml__roots_block *caml_local_roots;  /* defined in roots.c */
   return; \
 }while (0)
 
-#define CAMLreturn(result) do{ \
-  value caml__temp_result = (result); \
+#define CAMLreturnT(type, result) do{ \
+  type caml__temp_result = (result); \
   caml_local_roots = caml__frame; \
   return (caml__temp_result); \
 }while(0)
 
+#define CAMLreturn(result) CAMLreturnT(value, result)
+
 #define CAMLnoreturn ((void) caml__frame)
 
 
@@ -325,5 +327,33 @@ CAMLextern void caml_register_global_root (value *);
 
 CAMLextern void caml_remove_global_root (value *);
 
+/* [caml_register_generational_global_root] registers a global C
+   variable as a memory root for the duration of the program, or until
+   [caml_remove_generational_global_root] is called.
+   The program guarantees that the value contained in this variable
+   will not be assigned directly.  If the program needs to change
+   the value of this variable, it must do so by calling
+   [caml_modify_generational_global_root].  The [value *] pointer
+   passed to [caml_register_generational_global_root] must contain
+   a valid Caml value before the call.
+   In return for these constraints, scanning of memory roots during
+   minor collection is made more efficient. */
+
+CAMLextern void caml_register_generational_global_root (value *);
+
+/* [caml_remove_generational_global_root] removes a memory root
+   registered on a global C variable with
+   [caml_register_generational_global_root]. */
+
+CAMLextern void caml_remove_generational_global_root (value *);
+
+/* [caml_modify_generational_global_root(r, newval)]
+   modifies the value contained in [r], storing [newval] inside.
+   In other words, the assignment [*r = newval] is performed,
+   but in a way that is compatible with the optimized scanning of
+   generational global roots.  [r] must be a global memory root
+   previously registered with [caml_register_generational_global_root]. */
+
+CAMLextern void caml_modify_generational_global_root(value *r, value newval);
 
 #endif /* CAML_MEMORY_H */
