@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: map.mli,v 1.32 2004/04/23 10:01:33 xleroy Exp $ *)
+(* $Id: map.mli,v 1.33.18.1 2009/03/21 16:35:48 xleroy Exp $ *)
 
 (** Association tables over ordered types.
 
@@ -20,10 +20,10 @@
    over the keys.
    All operations over maps are purely applicative (no side-effects).
    The implementation uses balanced binary trees, and therefore searching
-   and insertion take time logarithmic in the size of the map. 
+   and insertion take time logarithmic in the size of the map.
 *)
 
-module type OrderedType = 
+module type OrderedType =
   sig
     type t
       (** The type of the map keys. *)
@@ -73,9 +73,7 @@ module type S =
     (** [iter f m] applies [f] to all bindings in map [m].
        [f] receives the key as first argument, and the associated value
        as second argument.  The bindings are passed to [f] in increasing
-       order with respect to the ordering over the type of the keys.
-       Only current bindings are presented to [f]:
-       bindings hidden by more recent bindings are not passed to [f]. *)
+       order with respect to the ordering over the type of the keys. *)
 
     val map: ('a -> 'b) -> 'a t -> 'b t
     (** [map f m] returns a map with same domain as [m], where the
@@ -109,4 +107,3 @@ module type S =
 module Make (Ord : OrderedType) : S with type key = Ord.t
 (** Functor building an implementation of the map structure
    given a totally ordered type. *)
-
