@@ -9,7 +9,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: odoc_info.mli,v 1.36.4.3 2005/02/18 16:08:37 guesdon Exp $ *)
+(* $Id: odoc_info.mli,v 1.45 2008/07/25 13:28:23 guesdon Exp $ *)
 
 (** Interface to the information collected in source files. *)
 
@@ -52,6 +52,7 @@ and text_element = Odoc_types.text_element =
   | Module_list of string list
        (** The table of the given modules with their abstract. *)
   | Index_list (** The links to the various indexes (values, types, ...) *)
+  | Custom of string * text (** to extend \{foo syntax *)
 
 (** A text is a list of [text_element]. The order matters. *)
 and text = text_element list
@@ -186,6 +187,9 @@ module Exception :
 (** Representation and manipulation of types.*)
 module Type :
   sig
+    type private_flag = Odoc_type.private_flag =
+      Private | Public
+
     (** Description of a variant type constructor. *)
     type variant_constructor = Odoc_type.variant_constructor =
         {
@@ -206,10 +210,10 @@ module Type :
     (** The various kinds of a type. *)
     type type_kind = Odoc_type.type_kind =
         Type_abstract (** Type is abstract, for example [type t]. *)
-      | Type_variant of variant_constructor list * bool
-                   (** constructors * bool *)
-      | Type_record of record_field list * bool
-	           (** fields * bool *)
+      | Type_variant of variant_constructor list
+                   (** constructors *)
+      | Type_record of record_field list
+                   (** fields *)
 
     (** Representation of a type. *)
     type t_type = Odoc_type.t_type =
@@ -218,7 +222,8 @@ module Type :
           mutable ty_info : info option ; (** Information found in the optional associated comment. *)
           ty_parameters : (Types.type_expr * bool * bool) list ;
                     (** type parameters: (type, covariant, contravariant) *)
-          ty_kind : type_kind ; (** Type kind. *)
+          ty_kind : type_kind; (** Type kind. *)
+          ty_private : private_flag; (** Private or public type. *)
           ty_manifest : Types.type_expr option; (** Type manifest. *)
           mutable ty_loc : location ;
           mutable ty_code : string option;
@@ -246,6 +251,7 @@ module Value :
         {
           att_value : t_value ; (** an attribute has almost all the same information as a value *)
           att_mutable : bool ;  (** [true] if the attribute is mutable. *)
+          att_virtual : bool ;  (** [true] if the attribute is virtual. *)
         }
 
     (** Representation of a class method. *)
@@ -409,7 +415,7 @@ module Module :
         {
           im_name : Name.t ; (** Complete name of the included module. *)
           mutable im_module : mmt option ; (** The included module or module type, if we found it. *)
-	  mutable im_info : Odoc_types.info option ; (** comment associated to the includ directive *)
+          mutable im_info : Odoc_types.info option ; (** comment associated to the includ directive *)
         }
 
     and module_alias = Odoc_module.module_alias =
@@ -419,10 +425,10 @@ module Module :
         }
 
     and module_parameter = Odoc_module.module_parameter = {
-	mp_name : string ; (** the name *)
-	mp_type : Types.module_type ; (** the type *)
-	mp_type_code : string ; (** the original code *)
-	mp_kind : module_type_kind ; (** the way the parameter was built *)
+        mp_name : string ; (** the name *)
+        mp_type : Types.module_type ; (** the type *)
+        mp_type_code : string ; (** the original code *)
+        mp_kind : module_type_kind ; (** the way the parameter was built *)
       }
 
     (** Different kinds of a module. *)
@@ -443,15 +449,16 @@ module Module :
     and t_module = Odoc_module.t_module =
         {
           m_name : Name.t ; (** Complete name of the module. *)
-          m_type : Types.module_type ; (** The type of the module. *)
+          mutable m_type : Types.module_type ; (** The type of the module. *)
           mutable m_info : info option ; (** Information found in the optional associated comment. *)
           m_is_interface : bool ; (** [true] for modules read from interface files *)
           m_file : string ; (** The file the module is defined in. *)
           mutable m_kind : module_kind ; (** The way the module is defined. *)
           mutable m_loc : location ;
           mutable m_top_deps : Name.t list ; (** The toplevels module names this module depends on. *)
-	  mutable m_code : string option ; (** The whole code of the module *)
-	  mutable m_code_intf : string option ; (** The whole code of the interface of the module *)
+          mutable m_code : string option ; (** The whole code of the module *)
+          mutable m_code_intf : string option ; (** The whole code of the interface of the module *)
+          m_text_only : bool ; (** [true] if the module comes from a text file *)
         }
 
     and module_type_alias = Odoc_module.module_type_alias =
@@ -475,7 +482,7 @@ module Module :
         {
           mt_name : Name.t ; (** Complete name of the module type. *)
           mutable mt_info : info option ; (** Information found in the optional associated comment. *)
-          mt_type : Types.module_type option ; (** [None] means that the module type is abstract. *)
+          mutable mt_type : Types.module_type option ; (** [None] means that the module type is abstract. *)
           mt_is_interface : bool ; (** [true] for modules read from interface files. *)
           mt_file : string ; (** The file the module type is defined in. *)
           mutable mt_kind : module_type_kind option ;
@@ -709,6 +716,9 @@ val verbose : string -> unit
    error counter is incremented. *)
 val warning : string -> unit
 
+(** A flag to indicate whether ocamldoc warnings must be printed or not. *)
+val print_warnings : bool ref
+
 (** Increment this counter when an error is encountered.
    The ocamldoc tool will print the number of errors
    encountered exit with code 1 if this number is greater
@@ -748,10 +758,11 @@ val info_string_of_info : info -> string
 (** [info_of_comment_file file] parses the given file
    and return an {!Odoc_info.info} structure. The content of the
    file must have the same syntax as the content of a special comment.
+   The given module list is used for cross reference.
    @raise Failure is the file could not be opened or there is a
    syntax error.
 *)
-val info_of_comment_file : string -> info
+val info_of_comment_file : Module.t_module list -> string -> info
 
 (** [remove_ending_newline s] returns [s] without the optional ending newline. *)
 val remove_ending_newline : string -> string
@@ -917,12 +928,13 @@ module Args :
     sig
       (** The kind of source file in arguments. *)
       type source_file =
-	  Impl_file of string
-	| Intf_file of string
+          Impl_file of string
+        | Intf_file of string
+        | Text_file of string
 
       (** The class type of documentation generators. *)
       class type doc_generator =
-	object method generate : Module.t_module list -> unit end
+        object method generate : Module.t_module list -> unit end
 
       (** The file used by the generators outputting only one file. *)
       val out_file : string ref
@@ -933,6 +945,12 @@ module Args :
       (** The optional title to use in the generated documentation. *)
       val title : string option ref
 
+      (** To inverse [.ml] and [.mli] files while merging comments. *)
+      val inverse_merge_ml_mli : bool ref
+
+      (** To filter module elements according to module type constraints. *)
+      val filter_with_module_constraints : bool ref
+
       (** To keep the code while merging, when we have both .ml and .mli files for a module. *)
       val keep_code : bool ref
 
@@ -940,7 +958,7 @@ module Args :
       val intro_file : string option ref
 
       (** Flag to indicate whether we must display the complete list of parameters
-	 for functions and methods. *)
+         for functions and methods. *)
       val with_parameter_list : bool ref
 
       (** The list of module names to hide. *)
@@ -958,6 +976,10 @@ module Args :
       (** To colorize code in HTML generated documentation pages, not code pages. *)
       val colorize_code : bool ref
 
+      (** To display functors in short form rather than with "functor ... -> ",
+         in HTML generated documentation. *)
+      val html_short_functors : bool ref
+
       (** The flag which indicates if we must generate a header (for LaTeX). *)
       val with_header : bool ref
 
