@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: parsing.ml,v 1.18 2004/01/01 16:42:40 doligez Exp $ *)
+(* $Id: parsing.ml,v 1.19.2.1 2009/01/13 15:17:51 doligez Exp $ *)
 
 (* The parsing engine *)
 
@@ -78,6 +78,9 @@ external parse_engine :
     parse_tables -> parser_env -> parser_input -> Obj.t -> parser_output
     = "caml_parse_engine"
 
+external set_trace: bool -> bool
+    = "caml_set_parser_trace"
+
 let env =
   { s_stack = Array.create 100 0;
     v_stack = Array.create 100 (Obj.repr ());
@@ -177,9 +180,15 @@ let peek_val env n =
   Obj.magic env.v_stack.(env.asp - n)
 
 let symbol_start_pos () =
-  if env.rule_len > 0
-  then env.symb_start_stack.(env.asp - env.rule_len + 1)
-  else env.symb_end_stack.(env.asp)
+  let rec loop i =
+    if i <= 0 then env.symb_end_stack.(env.asp)
+    else begin
+      let st = env.symb_start_stack.(env.asp - i + 1) in
+      let en = env.symb_end_stack.(env.asp - i + 1) in
+      if st <> en then st else loop (i - 1)
+    end
+  in
+  loop env.rule_len
 ;;
 let symbol_end_pos () = env.symb_end_stack.(env.asp);;
 let rhs_start_pos n = env.symb_start_stack.(env.asp - (env.rule_len - n));;
